Module Name:    src
Committed By:   joerg
Date:           Thu Dec  4 21:50:29 UTC 2014

Modified Files:
        src/sys/dev/ic: ahcisata_core.c

Log Message:
Increase reset delay in polling mode to 10ms per loop. It seems like
AHCI on the Cubietruck doesn't like the tigther loop.

PR 49448.


To generate a diff of this commit:
cvs rdiff -u -r1.52 -r1.53 src/sys/dev/ic/ahcisata_core.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/ic/ahcisata_core.c
diff -u src/sys/dev/ic/ahcisata_core.c:1.52 src/sys/dev/ic/ahcisata_core.c:1.53
--- src/sys/dev/ic/ahcisata_core.c:1.52	Sun Nov 23 01:38:49 2014
+++ src/sys/dev/ic/ahcisata_core.c	Thu Dec  4 21:50:29 2014
@@ -1,4 +1,4 @@
-/*	$NetBSD: ahcisata_core.c,v 1.52 2014/11/23 01:38:49 joerg Exp $	*/
+/*	$NetBSD: ahcisata_core.c,v 1.53 2014/12/04 21:50:29 joerg Exp $	*/
 
 /*
  * Copyright (c) 2006 Manuel Bouyer.
@@ -26,7 +26,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: ahcisata_core.c,v 1.52 2014/11/23 01:38:49 joerg Exp $");
+__KERNEL_RCSID(0, "$NetBSD: ahcisata_core.c,v 1.53 2014/12/04 21:50:29 joerg Exp $");
 
 #include <sys/types.h>
 #include <sys/malloc.h>
@@ -639,10 +639,12 @@ ahci_exec_fis(struct ata_channel *chp, i
 	/*
 	 * Base timeout is specified in ms.
 	 * If we are allowed to sleep, wait a tick each round.
 	 * Otherwise delay for 1ms on each round.
 	 */
 	if (flags & AT_WAIT)
 		timeout = MAX(1, mstohz(timeout));
+	else
+		timeout = timeout / 10;
 
 	AHCI_CMDH_SYNC(sc, achp, 0, BUS_DMASYNC_PREREAD | BUS_DMASYNC_PREWRITE);
 	/* start command */
@@ -669,7 +671,7 @@ ahci_exec_fis(struct ata_channel *chp, i
 		if (flags & AT_WAIT)
 			tsleep(&sc, PRIBIO, "ahcifis", 1);
 		else
-			delay(1000);
+			delay(10000);
 	}
 
 	aprint_debug("%s channel %d: timeout sending FIS\n",
@@ -639,10 +639,12 @@ ahci_exec_fis(struct ata_channel *chp, i
 	 * Base timeout is specified in ms.
 	 * If we are allowed to sleep, wait a tick each round.
-	 * Otherwise delay for 1ms on each round.
+	 * Otherwise delay for 10ms on each round.
 	 */
 	if (flags & AT_WAIT)

Reply via email to